==> odps-center-api-1.1.21-sources.jar: cn/com/duiba/odps/center/api/dto/OdpsSeckillActDetailDto.java <==
package cn.com.duiba.odps.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * @author JunAngLiu
 * @Title: OdpsSeckillActGoodsDataDto
 * @Description: 秒杀活动商品数据
 * @date 2019/2/2817:25
 */
public class OdpsSeckillActDetailDto implements Serializable {
    private static final long serialVersionUID = -1376222366625029230L;

    /**
     * 活动id
     */
    private Long seckillActId;
    /**
     * 日期
     */
    private Date curDate;
    /**
     * 销售量
     */
    private Long sales;
    /**
     * 交易用户数
     */
    private Long tradeUserAmount;

    /**
     * 交易金额
     */
    private Long tradeMoneyAmount;
    /**
     * 交易积分数
     */
    private Long tradeCreditsAmount;
    /**
     * 商品名称
     */
    private String goodsName;

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Long getSales() {
        return sales;
    }

    public void setSales(Long sales) {
        this.sales = sales;
    }

    public Long getTradeUserAmount() {
        return tradeUserAmount;
    }

    public void setTradeUserAmount(Long tradeUserAmount) {
        this.tradeUserAmount = tradeUserAmount;
    }

    public Long getTradeMoneyAmount() {
        return tradeMoneyAmount;
    }

    public void setTradeMoneyAmount(Long tradeMoneyAmount) {
        this.tradeMoneyAmount = tradeMoneyAmount;
    }

    public Long getTradeCreditsAmount() {
        return tradeCreditsAmount;
    }

    public void setTradeCreditsAmount(Long tradeCreditsAmount) {
        this.tradeCreditsAmount = tradeCreditsAmount;
    }

    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName;
    }

    public Long getSeckillActId() {
        return seckillActId;
    }

    public void setSeckillActId(Long seckillActId) {
        this.seckillActId = seckillActId;
    }
}

==> odps-center-api-1.3.56-20251014.124849-1-sources.jar: cn/com/duiba/odps/center/api/dto/OdpsSeckillActDetailDto.java <==
package cn.com.duiba.odps.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * @author JunAngLiu
 * @Title: OdpsSeckillActGoodsDataDto
 * @Description: 秒杀活动商品数据
 * @date 2019/2/2817:25
 */
public class OdpsSeckillActDetailDto implements Serializable {
    private static final long serialVersionUID = -1376222366625029230L;

    /**
     * 活动id
     */
    private Long seckillActId;
    /**
     * 日期
     */
    private Date curDate;
    /**
     * 销售量
     */
    private Long sales;
    /**
     * 交易用户数
     */
    private Long tradeUserAmount;

    /**
     * 交易金额
     */
    private Long tradeMoneyAmount;
    /**
     * 交易积分数
     */
    private Long tradeCreditsAmount;
    /**
     * 商品名称
     */
    private String goodsName;

    /**
     * 参与按钮点击pv
     */
    private Integer joinButtonPv;

    /**
     * 参与按钮点击uv
     */
    private Integer joinButtonUv;

    /**
     * 参与按钮曝光pv
     */
    private Integer joinButtonExportPv;

    /**
     * 参与按钮曝光uv
     */
    private Integer joinButtonExportUv;

    public Integer getJoinButtonPv() {
        return joinButtonPv;
    }

    public void setJoinButtonPv(Integer joinButtonPv) {
        this.joinButtonPv = joinButtonPv;
    }

    public Integer getJoinButtonUv() {
        return joinButtonUv;
    }

    public void setJoinButtonUv(Integer joinButtonUv) {
        this.joinButtonUv = joinButtonUv;
    }

    public Integer getJoinButtonExportPv() {
        return joinButtonExportPv;
    }

    public void setJoinButtonExportPv(Integer joinButtonExportPv) {
        this.joinButtonExportPv = joinButtonExportPv;
    }

    public Integer getJoinButtonExportUv() {
        return joinButtonExportUv;
    }

    public void setJoinButtonExportUv(Integer joinButtonExportUv) {
        this.joinButtonExportUv = joinButtonExportUv;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public Long getSales() {
        return sales;
    }

    public void setSales(Long sales) {
        this.sales = sales;
    }

    public Long getTradeUserAmount() {
        return tradeUserAmount;
    }

    public void setTradeUserAmount(Long tradeUserAmount) {
        this.tradeUserAmount = tradeUserAmount;
    }

    public Long getTradeMoneyAmount() {
        return tradeMoneyAmount;
    }

    public void setTradeMoneyAmount(Long tradeMoneyAmount) {
        this.tradeMoneyAmount = tradeMoneyAmount;
    }

    public Long getTradeCreditsAmount() {
        return tradeCreditsAmount;
    }

    public void setTradeCreditsAmount(Long tradeCreditsAmount) {
        this.tradeCreditsAmount = tradeCreditsAmount;
    }

    public String getGoodsName() {
        return goodsName;
    }

    public void setGoodsName(String goodsName) {
        this.goodsName = goodsName;
    }

    public Long getSeckillActId() {
        return seckillActId;
    }

    public void setSeckillActId(Long seckillActId) {
        this.seckillActId = seckillActId;
    }
}
